# chitChat Package

Welcome to chitChat, a python chat server package!

To run the server and client, enter into the python REPL:

`python`

To run the server from the REPL:

`from chitChat_pkg import server
server.app.run()`


To run a client from the REPL:

`from chitChat_pkg import client`